@@ -22,21 +22,36 @@
 #ifndef __SIDEBARWIDGET_H__
 #define __SIDEBARWIDGET_H__
 
+#include <tqwidget.h>
 
-#include <sidebarwidgetbase.h>
-#include <tqvbox.h>
+class TQVBox;
+class TQVBoxLayout;
+class TQScrollView;
+class KCMultiDialog;
+class DCOPRef;
 
-class sidebarwidget : public sidebarwidgetbase
+class sidebarwidget : public TQWidget
 {
 Q_OBJECT
-  
-public:
+
+  public:
     sidebarwidget(TQWidget* parent, const char* name = 0);
     virtual ~sidebarwidget();
-    void addWidget(TQWidget *w, const TQString &s);
     TQWidget *viewport();
+    TQScrollView *reportGrid;
+    TQVBoxLayout *mainLayout;
+    TQVBoxLayout *layout;
     TQVBox *view;
 
+
+  private slots:
+    void slotRefresh();
+    void slotConfigure();
+
+  private:
+    DCOPRef *dcopCall;
+    KCMultiDialog *settingsDialog = 0;
+
 };
 
 #endif
